============
SMART REDIS
============

it is SMAAAART!!

Quick start
-----------
0. Install packages::

    pip install django-smart-redis

1. Add "django_smart_redis" to your INSTALLED_APPS setting like this::

    INSTALLED_APPS = [
        ...
        'django_smart_redis',
        ...
    ]

2. Settings::

    SMART_REDIS_HOST='127.0.0.1'
    SMART_REDIS_PORT=6379
    SMART_REDIS_DB=0
    SMART_REDIS_PASSWORD="pswd"
    SMART_REDIS_NAMESPACE="cache"

2. Example code:

Coming soon...